@@ -1,7 +1,7 @@
 #
 # apt_preferences.rb - ruby interface for apt preferences
-# Copyright (c) 2004 Masato Taruishi <taru@debian.org>
-# Copyright (c) 2009 Francesco Poli <frx@firenze.linux.it>
+# Copyright (C) 2004       Masato Taruishi <taru@debian.org>
+# Copyright (C) 2009-2013  Francesco Poli <invernomuto@paranoici.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ module Debian
           if /(\S+): (.+)$/ =~ line
             self[$1] = "" if self[$1] == nil
             self[$1] << $2
-	  end
+          end
         end
       end
 
@@ -74,10 +74,10 @@ module Debian
 
     attr_reader :pins
 
-    def filter( pkgs = [], out = $stdout )
+    def filter( pkg_keys = [], out = $stdout )
       _each_pin do |pin|
         p = Pin.new(pin)
-        if ! p.listbugs? || pkgs.include?( p["Package"] )
+        if ! p.listbugs? || pkg_keys.include?( p["Package"] )
           out.puts pin
           out.puts ""
         end
@@ -94,12 +94,12 @@ if __FILE__ == $0
   p.pins.each do |pin|
     buf << " " + pin["Package"] if pin.listbugs?
   end
-  pinnedpkgs = buf.split(' ')
-  bugpkgs = []
+  pinned_pkg_keys = buf.split(' ')
+  buggy_pkg_keys = []
   open("|/usr/sbin/apt-listbugs -q list #{buf} | tail -n 1 ") { |io|
     buf = io.read.delete!(' ').gsub!(/\([^\)]+\)/,'')
-    bugpkgs = buf.split(',')
+    buggy_pkg_keys = buf.split(',')
   }
-  $stderr.puts "#{(pinnedpkgs - bugpkgs).join(', ')} has been fixed"
-  p.filter( bugpkgs )
+  $stderr.puts "#{(pinned_pkg_keys - buggy_pkg_keys).join(', ')} has been fixed"
+  p.filter( buggy_pkg_keys )
 end
